@@ -127,15 +127,25 @@ def savePython(self):
     #body: things other than foor loop
     fOut.write('  fIn.seek(0)\n')
     lastOutput = 0
+    if not bool(self.periodicity):  #if no periodicity
+      fOut.write('  hdfBranch_ = fOut.create_group("test_1")\n')
+      fOut.write('  hdfBranch_.attrs["NX_class"] = b"NXentry"\n')
+      fOut.write('  hdfBranch = hdfBranch_.create_group("data")\n')
+      fOut.write('  hdfBranch.attrs["NX_class"] = b"NXdata"\n')
     for start in self.content:
       if 'start' in self.periodicity and start==int(self.periodicity['start']):
         fOut.write('  for idxTest in range(numberOfTests):\n')
-        fOut.write('    hdfBranch = fOut.create_group("Test"+str(idxTest+1))\n')
+        fOut.write('    hdfBranch_ = fOut.create_group("test_"+str(idxTest+1))\n')
+        fOut.write('    hdfBranch_.attrs["NX_class"] = b"NXentry"\n')
+        fOut.write('    hdfBranch = hdfBranch_.create_group("data")\n')
+        fOut.write('    hdfBranch.attrs["NX_class"] = b"NXdata"\n')
         inForLoop = True
       sect= self.content[start]
       if not sect.important:  #don't output unimportant items
         continue
-      branchName = 'hdfBranch' if sect.dClass in ['meta','primary'] and inForLoop else None
+      branchName = None
+      if ( sect.dClass in ['meta','primary'] and inForLoop ) or not bool(self.periodicity):
+        branchName = 'hdfBranch'
       line = self.content[start].toPY(start-lastOutput, self.content, branchName)
       if line:
         forLoopPrefix = '  ' if inForLoop else ''
@@ -157,6 +167,7 @@ def savePython(self):
     # FORMALIZED DESCRIPTION OF BINARY-FILE-STRUCTURE
     fOut.write("\n\n\n'''\n")
     fOut.write("# INFO: THIS PART IS LOADED BY MARBLE\n")
+    fOut.write('# version= 1.0\n')
     fOut.write('# meta='+json.dumps(self.meta)+'\n')
     fOut.write('# periodicity='+json.dumps(self.periodicity)+'\n')
     fOut.write('# length='+str(len(self.content))+'\n')
@@ -264,6 +275,9 @@ def plot(self, start, plotMode=1, show=True):
   valuesX = range(1, section.length+1)
   self.file.seek(start)
   data = self.file.read(section.byteSize())
+  if len(data) !=struct.calcsize(section.size()):
+    print('**ERROR: cannot plot size does not fit byte-length')
+    return None
   valuesY = struct.unpack(section.size(), data) #get data
   if plotMode==1:
     ax1 = plt.subplot(111)
@@ -321,19 +335,20 @@ import numpy as np
 import matplotlib.pyplot as plt
 from datetime import datetime
 
-convURI = 'https://raw.githubusercontent.com/NFDI4Chem/formaTAPIRest/main/cwl/"""+self.meta['ext']+"""2hdf.cwl'
-convVersion = '1.0'
+convURI = b'https://raw.githubusercontent.com/main/cwl/"""+self.meta['ext']+"""2hdf.cwl'
+convVersion = b'1.5'
 
 ## COMMON PART FOR ALL CONVERTERS
 fileNameIn = sys.argv[1]
 fileNameOut= os.path.splitext(fileNameIn)[0]+'.hdf5'
 fIn   = open(fileNameIn,'br')
 fOut  = h5py.File(fileNameOut, 'w')
-converter = fOut.create_group("converter")
-converter.attrs['uri'] =     convURI
-converter.attrs['version'] = convVersion
-converter.attrs['original file name'] = fileNameIn
+fOut.attrs['uri'] =     convURI
+fOut.attrs['version'] = convVersion
+fOut.attrs['original_file_name'] = fileNameIn
 md5Hash = hashlib.md5()
 md5Hash.update(fIn.read())
-converter.attrs['original md5-sum'] = md5Hash.hexdigest()
+fOut.attrs['original_md5sum'] = md5Hash.hexdigest()
+fOut.attrs['default'] = b'test_1'
+
 """
